rive
library
Classes
AABB
AdvanceRequestInterface
Interface for requesting advance/repaint from a higher-level controller.
Animation
A Rive animation that can be played on an artboard.
Artboard
A Rive artboard containing animations, state machines, and components.
ArtboardAtIndex
Selects the artboard at the given index.
ArtboardDefault
Selects the default artboard.
ArtboardNamed
Selects the artboard with the given name.
ArtboardPainter
ArtboardSelector
A selector for an artboard in a Rive file.
ArtboardWidgetPainter <T extends ProceduralPainter >
ArtboardWidgetRiveRenderer
AudioAsset
An audio asset embedded in or referenced by a Rive file.
AudioSource
AutoBind
Auto-bind with a boolean value
BasicArtboardPainter
BindableArtboard
A reference to an artboard that can be bound to a view model property.
BindByIndex
Bind by index with a number value
BindByInstance
Bind by view model instance
BindByName
Bind by name with a string value
BindEmpty
Empty binding
BitFieldLoc
Location of an integer within a bitfield.
https://en.wikipedia.org/wiki/C_syntax#Bit_fields
BooleanInput
A boolean state machine input.
CallbackHandler
ClosureCallbackHandler
Component
A component within a Rive artboard (node, bone, shape, etc.).
CursorVisualPosition
CustomBooleanProperty
A boolean custom property on a Rive event.
CustomNumberProperty
A numeric custom property on a Rive event.
CustomProperty <T >
A custom property on a Rive event.
CustomPropertyInterface <T >
Interface for custom properties attached to Rive events.
CustomStringProperty
A string custom property on a Rive event.
DashPathEffect
DataBind
A data bind option for a Rive file.
DataEnum
A view model enum that represents a list of values.
EmptyCallbackHandler
Event
A Rive event emitted by a state machine.
EventInterface
Interface for Rive events emitted by state machines.
EventListenerInterface
Interface for listening to Rive events from a state machine.
Factory
Factory for creating Rive rendering objects.
File
A loaded Rive file containing artboards, animations, and view models.
FileAsset
Base class for all file assets in a Rive file.
FileAssetInterface
Interface for Rive file assets (images, fonts, audio).
FileLoader
A class that loads a Rive file from an asset, URL, or file.
FlutterRenderer
FlutterRiveRenderBox
FlutterRiveRendererWidget
Font
FontAsset
A font asset embedded in or referenced by a Rive file.
GeneralEvent
A general purpose Rive event with optional custom properties.
HitTester
IAABB
ImageAsset
An image asset embedded in or referenced by a Rive file.
IndexRenderBuffer
Input
Base class for state machine inputs.
Mat2D
NumberInput
A numeric state machine input.
OpenUrlEvent
A Rive event that requests opening a URL.
PathCommand
PathInterface
PathMeasure
ProceduralPainter
ProjectionResult
Result of projecting a point onto a segment.
RawTextInput
A low level text input helper. Takes high level input and creates shaped
text, selection, and cursor. Does not handle scrolling internally.
RenderBuffer
Renderer
RenderGradient
RenderImage
RenderLinearGradient
RenderPaint
RenderPath
RenderRadialGradient
RenderText
RenderTexture
RenderTexturePainter
A painting context passed to a Rive RenderTexture widget which will invoke
the paint method as necessary to paint into the texture with a Rive
renderer.
Rive
RiveArtboardWidget
RiveDefaults
RiveFailed
The state when the Rive file, controller, or view model instance fails to
load.
RiveFileWidget
RiveLoaded
The state when the Rive file is loaded and the controller is created.
RiveLoading
The state when the Rive file is still loading.
RiveNative
RiveNativeRenderBox
RivePainter
Base class for a Rive painter.
RivePanel
A widget that creates a shared texture to paint multiple RiveWidget s to.
RiveProceduralRenderingWidget
RiveRenderBox <T extends RivePainter >
RiveSharedTexture
Inherited widget that will pass the background render texture down the tree
RiveState
The state of the RiveBuilder widget.
RiveWidget
A widget that displays a Rive artboard.
RiveWidgetBuilder
A widget that builds a Rive file.
RiveWidgetController
This controller builds on top of the concept of a Rive painter, but
provides a more convenient API for building Rive widgets.
Segment2D
A line segment with a discrete start and end .
SharedRenderTexture
EXPERIMENTAL : This API may change or be removed in a future release.
SharedTextureArtboardWidgetPainter
SharedTexturePainter
EXPERIMENTAL : This API may change or be removed in a future release.
SharedTextureView
Renderers the artboard to a sharedTexture .
SharedTextureViewRenderer
SharedTextureViewRenderObject
SingleAnimationPainter
StateMachine
A Rive state machine that drives animations based on inputs and logic.
StateMachineAtIndex
Selects the state machine at the given index.
StateMachineDefault
Selects the default state machine.
StateMachineNamed
Selects the state machine with the given name.
StateMachinePainter
StateMachineSelector
A selector for a state machine in a Rive file.
TextValueRunRuntime
A text run value in a Rive artboard.
TransformComponents
TransformingHitTester
A HitTester with a settable transform. We can roll this into HitTester if we
like it.
TriggerInput
A trigger state machine input.
TrimPathEffect
UnimplementedRenderTexture
UnknownAsset
An unrecognized asset type in a Rive file.
Vec2D
VertexRenderBuffer
ViewModel
A Rive View Model as created in the Rive editor.
ViewModelInstance
An instance of a Rive ViewModel that can be used to access and modify
properties in the view model.
ViewModelInstanceArtboard
A Rive view model property that holds a reference to an artboard.
ViewModelInstanceAssetImage
A Rive view model property of type RenderImage that represents an asset
image value.
ViewModelInstanceBoolean
A Rive view model property of type bool that represents a boolean value.
ViewModelInstanceCallbacks
ViewModelInstanceColor
A Rive view model property of type Color that represents a color value.
ViewModelInstanceEnum
A Rive view model property of type String that represents an enumerator
value.
ViewModelInstanceList
A Rive view model property of type List<ViewModelInstance> that represents
a list of view model instances.
ViewModelInstanceNumber
A Rive view model property of type double that represents a number value.
ViewModelInstanceObservableValue <T >
ViewModelInstanceString
A Rive view model property of type String that represents a string value.
ViewModelInstanceSymbolListIndex
A Rive view model property of type int that represents the list index.
ViewModelInstanceTrigger
A Rive view model property of type bool that represents a trigger value.
ViewModelInstanceValue
ViewModelProperty
A representation of a property in a Rive view model.