Interface for listening to Rive events from a state machine.
Properties
- eventListenerCount → int
-
The number of registered event listeners.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEventListener(
OnRiveEvent callback) → void - Adds a listener to receive Rive events.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAllEventListeners(
) → void - Removes all registered event listeners.
-
removeEventListener(
OnRiveEvent callback) → void - Removes a previously added event listener.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited