FixedRenderResolution class final

Inheritance

Constructors

FixedRenderResolution(int width, int height)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
Backing store height in physical pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Backing store width in physical pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override