Input class abstract

Base class for state machine inputs.

@Deprecated Use Data Binding instead of state machine inputs.

Constructors

Input()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this input.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Releases resources associated with this input.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited