AssetLoaderCallback typedef
Callback for custom asset loading.
Return true if the asset was handled, false to use default loading.
The bytes parameter contains embedded asset data, or null if the asset
should be loaded from CDN.
Implementation
typedef AssetLoaderCallback = bool Function(
FileAsset fileAsset, Uint8List? bytes);