defaultArtboard abstract method
Returns the default artboard from this file, or null if none exists.
Set frameOrigin to false to position the artboard at its original
coordinates rather than centering it at (0, 0).
Implementation
Artboard? defaultArtboard({bool frameOrigin = true});