Input class abstract
Base class for state machine inputs.
@Deprecated Use Data Binding instead of state machine inputs.
Constructors
- Input()
Properties
Methods
-
dispose(
) → void - Releases resources associated with this input.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited